[llvm-commits] CVS: llvm/include/llvm/CodeGen/MachineDebugInfo.h

Jim Laskey jlaskey at apple.com
Mon Feb 13 04:51:02 PST 2006



Changes in directory llvm/include/llvm/CodeGen:

MachineDebugInfo.h updated: 1.14 -> 1.15
---
Log message:

Rename to better reflect usage (current and planned.)


---
Diffs of the changes:  (+3 -2)

 MachineDebugInfo.h |    5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)


Index: llvm/include/llvm/CodeGen/MachineDebugInfo.h
diff -u llvm/include/llvm/CodeGen/MachineDebugInfo.h:1.14 llvm/include/llvm/CodeGen/MachineDebugInfo.h:1.15
--- llvm/include/llvm/CodeGen/MachineDebugInfo.h:1.14	Fri Feb 10 19:01:30 2006
+++ llvm/include/llvm/CodeGen/MachineDebugInfo.h	Mon Feb 13 06:50:38 2006
@@ -584,9 +584,10 @@
   ///
   bool doFinalization();
   
   /// Deserialize - Convert a Value to a debug information descriptor.
   ///
-  DebugInfoDesc *Deserialize(Value *V);
+  // FIXME - use new Value type when available.
+  DebugInfoDesc *getDescFor(Value *V);
   
   /// Verify - Verify that a Value is debug information descriptor.
   ///
@@ -584,9 +584,10 @@
   bool doFinalization();
   
-  /// Deserialize - Convert a Value to a debug information descriptor.
+  /// getDescFor - Convert a Value to a debug information descriptor.
   ///






More information about the llvm-commits mailing list